@@ -113,11 +113,16 @@ class ContainerLauncher:
                     'region': self.__region
                 })
                 self.logger.debug('Getting an optimal instance type')
-                instance_type = ec2.get_optimal_instance_type({
+                get_optimal_instance_type_input = {
                     'cpu': container_input['cpu'],
                     'memory': container_input['memory'],
                     'usage_class': usage_class
-                })
+                }
+                ssd_instance_stores = [storage for storage in storages if storage['type'] == 'ssd_instance_store']
+                if len(ssd_instance_stores) > 0:
+                    get_optimal_instance_type_input['is_instance_storage_supported'] = True
+
+                instance_type = ec2.get_optimal_instance_type(get_optimal_instance_type_input)
                 self.logger.debug(f'The optimal instance type is {instance_type}')
 
             cpu = self.__get_cpu_for_instance(instance_type)
@@ -126,7 +131,9 @@ class ContainerLauncher:
 
             docker_image = container_input['docker_image']
             ami = container_input['ami'] if container_input.get('ami') \
-                else Ec2().get_image_id({'instance_type': instance_type})
+                else Ec2({
+                'region': self.__region
+            }).get_image_id({'instance_type': instance_type})
             subnet_ids = container_input['subnet_ids']
 
             ec2_iam_role_arn = self.__create_ec2_iam_role()
@@ -420,7 +427,8 @@ class ContainerLauncher:
         try:
             if self.__resources.get('asg_scale_in_alarm_name'):
                 self.clients['cloudwatch'].delete_alarms(AlarmNames=[self.__resources['asg_scale_in_alarm_name']])
-                self.logger.debug(f"The Cloudwatch alarm {self.__resources['asg_scale_in_alarm_name']} has been deleted")
+                self.logger.debug(
+                    f"The Cloudwatch alarm {self.__resources['asg_scale_in_alarm_name']} has been deleted")
         except Exception as e:
             self.logger.warning(f'An error occurred during the delete_alarms operation: {str(e)}')
         try:
@@ -470,7 +478,8 @@ class ContainerLauncher:
             if self.__resources.get('capacity_provider_name'):
                 self.clients['ecs'].delete_capacity_provider(
                     capacityProvider=self.__resources['capacity_provider_name'])
-                self.logger.debug(f"The capacity provider {self.__resources['capacity_provider_name']} has been deleted")
+                self.logger.debug(
+                    f"The capacity provider {self.__resources['capacity_provider_name']} has been deleted")
         except Exception as e:
             self.logger.warning(f'An error occurred during the delete_capacity_provider operation: {str(e)}')
         try:
@@ -940,20 +949,30 @@ class ContainerLauncher:
         if storages is not None:
             ssd_instance_stores = [storage for storage in storages if storage['type'] == 'ssd_instance_store']
             if len(ssd_instance_stores) > 0:
-                mount_ssd_instance_store_command = '''yum install mdadm -y
+                storage = ssd_instance_stores[0]
+                ssd_instance_store_dir = storage.get('dir', '/ssd')
+                ec2 = Ec2({
+                    'region': self.__region
+                })
+                if ec2.is_instance_storage_supported_for_instance_type(instance_type):
+                    mount_ssd_instance_store_command = '''yum install mdadm -y
 yum install jq -y
 mounts=($(lsblk --fs --json | jq -r '.blockdevices[] | select(.children == null and .fstype == null) | .name'))
 for i in "${mounts[@]}" ; do echo -e "o\\nn\\np\\n1\\n\\n\\nw" | fdisk /dev/$i ; done
+mounts_count=${#mounts[@]}
 dev_mounts=""
 for i in "${mounts[@]}" ; do dev_mounts="$dev_mounts /dev/$i" ; done
-echo $dev_mounts >> /etc/ecs/dev_mount_file.out
-echo -e "o\\ny" | mdadm --create --verbose --force --auto=yes /dev/md0 --level=0 --raid-devices=2 $dev_mounts >> /etc/ecs/dev_mount.out
+echo -e "o\\ny" | mdadm --create --verbose --force --auto=yes /dev/md0 --level=0 --raid-devices=$mounts_count $dev_mounts
 mkfs.ext4 /dev/md0
-mkdir /ssd
-echo /dev/md0 /ssd ext4 defaults 0 0 >> /etc/fstab
-mount /dev/md0 /ssd
-                '''
-                user_data = f'{user_data}\n{mount_ssd_instance_store_command}'
+mkdir %s
+echo /dev/md0 %s ext4 defaults 0 0 >> /etc/fstab
+mount /dev/md0 %s
+                    ''' % (ssd_instance_store_dir, ssd_instance_store_dir, ssd_instance_store_dir)
+                    user_data = f'{user_data}\n{mount_ssd_instance_store_command}'
+                else:
+                    self.logger \
+                        .warning(
+                        f'SSD instance store configuration is ignored because SSD instance store is requested, but {instance_type} is not supported instance store')
 
             fsx_storages = [storage for storage in storages if storage['type'] == 'fsx']
             if len(fsx_storages) > 0:
